#region License
// Copyright (c) 2007 James Newton-King
//
// Permission is hereby granted, free of charge, to any person
// obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without
// restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following
// conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
#endregion

using NUnit.Framework;
using Utilities.IO;
using Utilities.Testing;

namespace Utilities.Test.IO
{
  public class FileUtilsFixture : TestFixtureBase
  {
    [Test]
    public void ToValidFileName()
    {
      string fileName = FileUtils.ToValidFileName(@"NAT retest 23/01/07 - 24 Jan 2007 - Version 1.pdf");

      Assert.AreEqual("NAT retest 230107 - 24 Jan 2007 - Version 1.pdf", fileName);
    }

    [Test]
    public void ToValidFileNameUnderscoreSpaces()
    {
      string fileName = FileUtils.ToValidFileName(@"NAT retest 23/01/07 - 24 Jan 2007 - Version 1.pdf", string.Empty, "_");

      Assert.AreEqual("NAT_retest_230107_-_24_Jan_2007_-_Version_1.pdf", fileName);
    }

    [Test]
    public void ToValidFileNameNullSpaces()
    {
      string fileName = FileUtils.ToValidFileName(@"NAT retest 23/01/07 - 24 Jan 2007 - Version 1.pdf", string.Empty, string.Empty);

      Assert.AreEqual("NATretest230107-24Jan2007-Version1.pdf", fileName);
    }
  }
}